@@ -51,7 +51,7 @@ Exports the config to an image file using customized output options.`,
 	Args: cobra.NoArgs,
 	Run: func(_ *cobra.Command, _ []string) {
 		configFile := config.Path(configFlag)
-		cfg := config.Load(configFile, shell.GENERIC, false)
+		cfg, _ := config.Load(configFile, shell.GENERIC, false)
 
 		flags := &runtime.Flags{
 			Config:        configFile,
@@ -62,7 +62,7 @@ Exports the config to an image file using customized output options.`,
 		env := &runtime.Terminal{}
 		env.Init(flags)
 
-		template.Init(env, cfg.Var)
+		template.Init(env, cfg.Var, cfg.Maps)
 
 		defer func() {
 			template.SaveCache()
