@@ -1,8 +1,11 @@
 package prompt
 
 import (
+	"strconv"
 	"strings"
 
+	"slices"
+
 	"github.com/jandedobbeleer/oh-my-posh/src/config"
 	"github.com/jandedobbeleer/oh-my-posh/src/shell"
 	"github.com/jandedobbeleer/oh-my-posh/src/terminal"
@@ -13,11 +16,11 @@ func (e *Engine) Tooltip(tip string) string {
 	tooltips := make([]*config.Segment, 0, 1)
 
 	for _, tooltip := range e.Config.Tooltips {
-		if !e.shouldInvokeWithTip(tooltip, tip) {
+		if !slices.Contains(tooltip.Tips, tip) {
 			continue
 		}
 
-		tooltip.SetEnabled(e.Env)
+		tooltip.Execute(e.Env)
 
 		if !tooltip.Enabled {
 			continue
@@ -36,13 +39,14 @@ func (e *Engine) Tooltip(tip string) string {
 		Segments:  tooltips,
 	}
 
-	block.Init(e.Env)
+	text, length := e.writeBlockSegments(block)
 
-	if !block.Enabled() {
+	// do not print anything when we don't have any text
+	if length == 0 {
 		return ""
 	}
 
-	text, length := e.renderBlockSegments(block)
+	text, length = e.handleToolTipAction(text, length)
 
 	switch e.Env.Shell() {
 	case shell.PWSH, shell.PWSH5:
@@ -64,12 +68,34 @@ func (e *Engine) Tooltip(tip string) string {
 	}
 }
 
-func (e *Engine) shouldInvokeWithTip(segment *config.Segment, tip string) bool {
-	for _, t := range segment.Tips {
-		if t == tip {
-			return true
-		}
+func (e *Engine) handleToolTipAction(text string, length int) (string, int) {
+	if e.Config.ToolTipsAction.IsDefault() {
+		return text, length
 	}
 
-	return false
+	rprompt, OK := e.Env.Cache().Get(RPromptKey)
+	if !OK {
+		return text, length
+	}
+
+	rpromptLengthStr, OK := e.Env.Cache().Get(RPromptLengthKey)
+	if !OK {
+		return text, length
+	}
+
+	rpromptLength, err := strconv.Atoi(rpromptLengthStr)
+	if err != nil {
+		return text, length
+	}
+
+	length += rpromptLength
+
+	switch e.Config.ToolTipsAction {
+	case config.Extend:
+		text = rprompt + text
+	case config.Prepend:
+		text += rprompt
+	}
+
+	return text, length
 }
