@@ -78,18 +78,18 @@ type Flags struct {
 	PWD           string
 	AbsolutePWD   string
 	Type          string
-	ErrorCode     int
+	ConfigHash    string
+	SessionID     string
 	PromptCount   int
-	StackCount    int
 	Column        int
 	TerminalWidth int
 	ExecutionTime float64
+	StackCount    int
+	ErrorCode     int
 	JobCount      int
-	IsPrimary     bool
+	Strict        bool
 	HasExtra      bool
 	Debug         bool
-	Plain         bool
-	Strict        bool
 	Cleared       bool
 	NoExitCode    bool
 	SaveCache     bool
@@ -97,6 +97,8 @@ type Flags struct {
 	Migrate       bool
 	Eval          bool
 	Escape        bool
+	IsPrimary     bool
+	Plain         bool
 }
 
 type CommandError struct {
