@@ -11,9 +11,9 @@ import (
 
 func TestNodeMatchesVersionFile(t *testing.T) {
 	nodeVersion := version{
-		Full:  "20.14.0",
-		Major: "20",
-		Minor: "14",
+		Full:  "22.16.0",
+		Major: "22",
+		Minor: "16",
 		Patch: "0",
 	}
 	cases := []struct {
@@ -23,16 +23,16 @@ func TestNodeMatchesVersionFile(t *testing.T) {
 		Expected        bool
 	}{
 		{Case: "no file context", Expected: true, RCVersion: ""},
-		{Case: "version match", Expected: true, ExpectedVersion: "20.14.0", RCVersion: "20.14.0"},
-		{Case: "version match with newline", Expected: true, ExpectedVersion: "20.14.0", RCVersion: "20.14.0\n"},
+		{Case: "version match", Expected: true, ExpectedVersion: "22.16.0", RCVersion: "22.16.0"},
+		{Case: "version match with newline", Expected: true, ExpectedVersion: "22.16.0", RCVersion: "22.16.0\n"},
 		{Case: "version mismatch", Expected: false, ExpectedVersion: "3.2.1", RCVersion: "3.2.1"},
-		{Case: "version match in other format", Expected: true, ExpectedVersion: "20.14.0", RCVersion: "v20.14.0"},
-		{Case: "version match without patch", Expected: true, ExpectedVersion: "20.14", RCVersion: "20.14"},
-		{Case: "version match without patch in other format", Expected: true, ExpectedVersion: "20.14", RCVersion: "v20.14"},
-		{Case: "version match without minor", Expected: true, ExpectedVersion: "20", RCVersion: "20"},
-		{Case: "version match without minor in other format", Expected: true, ExpectedVersion: "20", RCVersion: "v20"},
-		{Case: "lts match", Expected: true, ExpectedVersion: "20.14.0", RCVersion: "lts/iron"},
-		{Case: "lts match upper case", Expected: true, ExpectedVersion: "20.14.0", RCVersion: "lts/Iron"},
+		{Case: "version match in other format", Expected: true, ExpectedVersion: "22.16.0", RCVersion: "v22.16.0"},
+		{Case: "version match without patch", Expected: true, ExpectedVersion: "22.16", RCVersion: "22.16"},
+		{Case: "version match without patch in other format", Expected: true, ExpectedVersion: "22.16", RCVersion: "v22.16"},
+		{Case: "version match without minor", Expected: true, ExpectedVersion: "22", RCVersion: "22"},
+		{Case: "version match without minor in other format", Expected: true, ExpectedVersion: "22", RCVersion: "v22"},
+		{Case: "lts match", Expected: true, ExpectedVersion: "22.16.0", RCVersion: "lts/jod"},
+		{Case: "lts match upper case", Expected: true, ExpectedVersion: "22.16.0", RCVersion: "lts/Jod"},
 		{Case: "lts mismatch", Expected: false, ExpectedVersion: "8.17.0", RCVersion: "lts/carbon"},
 	}
 
@@ -84,6 +84,7 @@ func TestNodeInContext(t *testing.T) {
 		env.On("HasFiles", "package-lock.json").Return(tc.hasNPM)
 		env.On("HasFiles", "package.json").Return(tc.hasDefault)
 		env.On("HasFiles", "bun.lockb").Return(tc.hasBun)
+		env.On("HasFiles", "bun.lock").Return(tc.hasBun)
 
 		props := properties.Map{
 			PnpmIcon:            "pnpm",
