@@ -2,7 +2,6 @@ package shell
 
 import (
 	_ "embed"
-
 	"fmt"
 	"strings"
 )
@@ -30,7 +29,7 @@ func (f Feature) Pwsh() Code {
 		return "& $global:_ompExecutable upgrade"
 	case Notice:
 		return "& $global:_ompExecutable notice"
-	case PromptMark, RPrompt, CursorPositioning:
+	case PromptMark, RPrompt, CursorPositioning, Async:
 		fallthrough
 	default:
 		return ""
@@ -38,5 +37,9 @@ func (f Feature) Pwsh() Code {
 }
 
 func quotePwshOrElvishStr(str string) string {
+	if len(str) == 0 {
+		return "''"
+	}
+
 	return fmt.Sprintf("'%s'", strings.ReplaceAll(str, "'", "''"))
 }
